@@ -138,33 +138,45 @@ bicomprisk <- function(formula, data, cause=c(1,1), cens=0, causes, indiv,
 
   ## {{{ (i,j) causes 
   idx2 <- which(ww0[,causes2[1]]==cause[1] & ww0[,causes2[2]]==cause[2])
-  status[idx2] <- 1
-  time[idx2] <- apply(ww0[idx2,timevar2[1:2]],1,max)
+  if (length(idx2)>0) {
+      status[idx2] <- 1
+      time[idx2] <- apply(ww0[idx2,timevar2[1:2],drop=FALSE],1,max)
+  }
 
   ##(0,0), (0,j)
   idx2 <- which(ww0[,causes2[1]]==cens & (ww0[,causes2[2]]==cens | ww0[,causes2[2]]==cause[2]))
-  status[idx2] <- 0
-  time[idx2] <- ww0[idx2,timevar2[1]]
+  if (length(idx2)>0) {
+      status[idx2] <- 0
+      time[idx2] <- ww0[idx2,timevar2[1]]
+  }
 
   ##(ic,0), (ic,j)
   idx2 <- which(ww0[,causes2[1]]!=cens & ww0[,causes2[1]]!=cause[1] & (ww0[,causes2[2]]==cens | ww0[,causes2[2]]==cause[2]))
-  status[idx2] <- 2
-  time[idx2] <- ww0[idx2,timevar2[1]]
+  if (length(idx2)>0) {
+      status[idx2] <- 2
+      time[idx2] <- ww0[idx2,timevar2[1]]
+  }
 
   ##(i,0)
   idx2 <- which(ww0[,causes2[1]]==cause[1] & ww0[,causes2[2]]==cens)
-  status[idx2] <- 0
-  time[idx2] <- ww0[idx2,timevar2[2]]
+  if (length(idx2)>0) {
+      status[idx2] <- 0
+      time[idx2] <- ww0[idx2,timevar2[2]]
+  }
 
   ##(ic,jc)
   idx2 <- which(ww0[,causes2[1]]!=cens & ww0[,causes2[1]]!=cause[1] & (ww0[,causes2[2]]!=cens & ww0[,causes2[2]]!=cause[2]))
-  status[idx2] <- 2
-  time[idx2] <- apply(ww0[idx2,timevar2[1:2]],1,min)
+  if (length(idx2)>0) {
+      status[idx2] <- 2
+      time[idx2] <- apply(ww0[idx2,timevar2[1:2],drop=FALSE],1,min)
+  }
 
   ##(0,jc),(i,jc)
   idx2 <- which((ww0[,causes2[1]]==cens | ww0[,causes2[1]]==cause[1]) & (ww0[,causes2[2]]!=cens & ww0[,causes2[2]]!=cause[2]))
-  status[idx2] <- 2
-  time[idx2] <- ww0[idx2,timevar2[2]]
+  if (length(idx2)>0) {
+      status[idx2] <- 2
+      time[idx2] <- ww0[idx2,timevar2[2]]
+  }
   
   mydata0 <- mydata <- data.frame(time,status,ww0[,covars2],ww0[,indiv2])
   names(mydata) <- c(timevar,causes,covars,indiv2)
