@@ -19,7 +19,7 @@ summary.biprobit <- function(object,level=0.05,...) {
     }
     mu.cond <- function(x) m[1]+S[1,2]/S[2,2]*(x-m[2])
     var.cond <- S[1,1]-S[1,2]^2/S[2,2]    
-    conc <- pmvnorm(upper=m,sigma=S)
+    conc <- pmvn(upper=m,sigma=S)
     marg <- pnorm(m[1],sd=S[1,1]^0.5)
     cond <- conc/marg
     logit(c(conc,cond,marg))
@@ -28,7 +28,7 @@ summary.biprobit <- function(object,level=0.05,...) {
   CIlab <- paste(c(alpha*100,100*(1-alpha)),"%",sep="")
   mycoef <- coef(object)
   prob <- probs(mycoef)
-  Dprob <- jacobian(probs,mycoef)
+  Dprob <- numDeriv::jacobian(probs,mycoef)
   sprob <- diag((Dprob)%*%vcov(object)%*%t(Dprob))^0.5
   pp <- tigol(cbind(prob,prob-qnorm(1-alpha)*sprob,prob+qnorm(1-alpha)*sprob))
   rownames(pp) <- c("Concordance","Case-wise/Conditional","Marginal")
